@@ -67,20 +67,20 @@ pub fn bench_downscale_rgb(bench: &mut Bench) {
     #[cfg(target_arch = "x86_64")]
     {
         cpu_ext_and_name.push((CpuExtensions::Sse4_1, "sse4.1"));
-        cpu_ext_and_name.push((CpuExtensions::Avx2, "avx2"));
+        // cpu_ext_and_name.push((CpuExtensions::Avx2, "avx2"));
     }
     for (cpu_ext, ext_name) in cpu_ext_and_name {
         for alg_name in alg_names {
-            let src_rgba_image = utils::get_big_rgba_image();
+            let src_buffer = src_image.as_raw();
             let src_image_data = Image::from_vec_u8(
                 NonZeroU32::new(src_image.width()).unwrap(),
                 NonZeroU32::new(src_image.height()).unwrap(),
-                src_rgba_image.into_raw(),
-                PixelType::U8x4,
+                src_buffer.clone(),
+                PixelType::U8x3,
             )
             .unwrap();
             let src_view = src_image_data.view();
-            let mut dst_image = Image::new(new_width, new_height, PixelType::U8x4);
+            let mut dst_image = Image::new(new_width, new_height, PixelType::U8x3);
             let mut dst_view = dst_image.view_mut();
 
             let resize_alg = match alg_name {
