@@ -5,7 +5,7 @@ pub(crate) fn multiply_alpha_native(
     src_image: TypedImageView<U8x4>,
     mut dst_image: TypedImageViewMut<U8x4>,
 ) {
-    let src_rows = src_image.iter_rows(0, src_image.height().get());
+    let src_rows = src_image.iter_rows(0);
     let dst_rows = dst_image.iter_rows_mut();
 
     for (src_row, dst_row) in src_rows.zip(dst_rows) {
@@ -21,17 +21,16 @@ pub(crate) fn multiply_alpha_inplace_native(mut image: TypedImageViewMut<U8x4>)
 }
 
 #[inline(always)]
-pub(crate) fn multiply_alpha_row_native(src_row: &[u32], dst_row: &mut [u32]) {
+pub(crate) fn multiply_alpha_row_native(src_row: &[U8x4], dst_row: &mut [U8x4]) {
     for (src_pixel, dst_pixel) in src_row.iter().zip(dst_row) {
-        let components: [u8; 4] = src_pixel.to_le_bytes();
+        let components: [u8; 4] = src_pixel.0.to_le_bytes();
         let alpha = components[3];
-        let res: [u8; 4] = [
+        dst_pixel.0 = u32::from_le_bytes([
             mul_div_255(components[0], alpha),
             mul_div_255(components[1], alpha),
             mul_div_255(components[2], alpha),
             alpha,
-        ];
-        *dst_pixel = u32::from_le_bytes(res);
+        ]);
     }
 }
 
